import { Component, OnInit, Inject, AfterContentInit } from '@angular/core';
import { ActivatedRoute, Router } from '@angular/router';
import { MatDialog, MatDialogRef, MAT_DIALOG_DATA } from '@angular/material';
import { Store, select } from '@ngrx/store';

import { RPCError } from 'packages/core/rpc/error';

import { ConfirmDialogComponent } from 'packages/commons/component/confirm-dialog/confirm-dialog.component';

import * as DetailStore from '../../store/detail';
import { DetailSelector } from '../../store';
import { Probe } from '../../model';

@Component({
  selector: 'of-probe-detail',
  templateUrl: './detail.component.html',
  styleUrls: ['./detail.component.scss']
})
export class DetailComponent implements OnInit, AfterContentInit {

  probe$ = this.detailStore.pipe(select(DetailSelector.select('probe')));
  probe: Probe = null;
  networkInfo = null;
  deviceInfo = null;
  probeInfo = null;


  constructor(
    private route: ActivatedRoute,
    private router: Router,
    public dialog: MatDialog,
    private detailStore: Store<DetailStore.State>
  ) { }

  ngOnInit() {
    this.probe$.subscribe(
      (probe: Probe) => {
        if (probe != null) {
          this.probe = probe;
          this.arrangeInfo();
        }
      },
      (error: RPCError) => {
        console.log(error.message);
      }
    );
  }

  ngAfterContentInit() {
    const probeId = this.route.snapshot.paramMap.get('id');
    this.detailStore.dispatch(
      new DetailStore.Read(
        { id: probeId }
      )
    );
  }

  arrangeInfo() {
    this.networkInfo = [
      {
        key: 'IP',
        value: '192.168.1.1'
      },
      {
        key: 'NIC',
        value: 'enps30'
      },
      {
        key: 'Targets',
        value: '12'
      },
    ];
    this.deviceInfo = [
      {
        key: 'OS',
        value: 'Linux'
      },
      {
        key: 'CPU',
        value: 'intel7...'
      },
      {
        key: 'Memory',
        value: '16GB'
      },
      {
        key: '...',
        value: '...'
      },
    ];
    this.probeInfo = [
      {
        key: 'Authorized at',
        value: String(new Date())
      },
      {
        key: 'Authorized by',
        value: 'insanity'
      },
      {
        key: 'Installed at',
        value: String(new Date())
      },
    ];
  }

  handleStartStop() {
    // this.isUpState = !this.isUpState;
  }

  handleRemove() {
    const dialogRef = this.dialog.open(ConfirmDialogComponent, {
      width: '250px',
      data: {
        title: 'Remove',
        message: 'Are you sure?'
      }
    });

    dialogRef.afterClosed().subscribe(confirmed => {
      if (confirmed) {
        console.log('confirmed');
      }
      // 삭제 후 list로 back
    });
  }
}

